# Changelog

## [0.2.0](https://github.com/agntcy/slim/compare/slimrpc-v0.1.0...slimrpc-v0.2.0) (2025-12-02)


### Features

* **slimrpc,slima2a,slim-mcp:** Upgrade to v0.7.1 slim_bindings ([#839](https://github.com/agntcy/slim/issues/839)) ([eedb157](https://github.com/agntcy/slim/commit/eedb157d63b1562eda4b92162f7183355632cc12))
* **slimrpc:** Add option to use existing local app for server ([#775](https://github.com/agntcy/slim/issues/775)) ([5e91347](https://github.com/agntcy/slim/commit/5e9134716159d18e1d25d22b4d2eb4a51062ecd3))

## [0.1.0](https://github.com/agntcy/slim/compare/slimrpc-v0.0.1...slimrpc-v0.1.0) (2025-09-18)


### Features

* rename srpc python import to slimrpc ([#660](https://github.com/agntcy/slim/issues/660)) ([d7ed9b2](https://github.com/agntcy/slim/commit/d7ed9b206c49096628541404766790c6a2406d7e))
* **slimrpc:** separate Channel and ChannelFactory ([#685](https://github.com/agntcy/slim/issues/685)) ([3dc8a5b](https://github.com/agntcy/slim/commit/3dc8a5b8a434180a275fcbce5f26b62b3739b4c9))
* **slimrpc:** Support existing slim binding in ChannelFactory ([#690](https://github.com/agntcy/slim/issues/690)) ([d7093b7](https://github.com/agntcy/slim/commit/d7093b7b022e5fc707ecef61953e6016f05e4a73))
* **srpc:** Add traceback in SRPC handler error log ([#613](https://github.com/agntcy/slim/issues/613)) ([1d566f6](https://github.com/agntcy/slim/commit/1d566f6918def5c6538bed4eca213517022ac75c))


### Bug Fixes

* **slima2a, slimrpc:** make mypy happy ([#671](https://github.com/agntcy/slim/issues/671)) ([5ab4628](https://github.com/agntcy/slim/commit/5ab462854c57a4788cc5eec8eecc734ab34cb2d5))
* **srpc:** Fix deadline handling ([#658](https://github.com/agntcy/slim/issues/658)) ([27ea70a](https://github.com/agntcy/slim/commit/27ea70aa5854220945fc72665f0f1640701b4f2f))


### Documentation

* update SRPC README ([#700](https://github.com/agntcy/slim/issues/700)) ([647dc47](https://github.com/agntcy/slim/commit/647dc47e2cafd77e4b6b20465fe28d13b5cfa2b2)), closes [#699](https://github.com/agntcy/slim/issues/699)

## 0.0.1 (2025-09-09)


### Features

* update version of slima2a and slimrpc wheels ([#637](https://github.com/agntcy/slim/issues/637)) ([e6569cb](https://github.com/agntcy/slim/commit/e6569cba88afff65b7a736f7511d9ea2a57f7dc2))
